@@ -46,7 +46,7 @@ def register_arguments(parser) -> None:
     # AWS Batch development options
     development = parser.add_argument_group(
         "development options for --aws-batch",
-        "See <https://github.com/nextstrain/cli/tree/master/doc/aws-batch.md>\nfor more information.")
+        "See <https://docs.nextstrain.org/projects/cli/page/aws-batch>\nfor more information.")
 
     development.add_argument(
         "--aws-batch-job",
@@ -87,6 +87,13 @@ def register_arguments(parser) -> None:
 
 
 def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, memory: int = None) -> int:
+    # Unlike other runners, the AWS Bach runner currently *requires* a working
+    # dir.  This is ok as we only provide the AWS Batch runner for commands
+    # which also require a working dir (e.g. build), whereas other runners also
+    # work with commands that don't.
+    #   -trs, 28 Feb 2022
+    assert working_volume is not None
+
     local_workdir = resolve_path(working_volume.src)
 
     if opts.attach:
@@ -267,8 +274,13 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
         s3.download_workdir(remote_workdir, local_workdir, patterns)
 
 
-    # Exit with the job's exit code, or assume success
-    return job.exit_code or 0
+    # Exit with the job's exit code if available or 1 if another failure,
+    # otherwise success.
+    return (
+        job.exit_code if job.exit_code is not None else
+                    1 if job.is_failed             else
+                    0
+    )
 
 
 def detach(job: jobs.JobState, local_workdir: Path) -> int:
